==> owlcarousel-3.0.0.tar.gz: owlcarousel/README.md <==
CONTENTS OF THIS FILE
---------------------

 * Introduction
 * Requirements
 * Features
 * Installation
 * Configuration
 * Maintainers
 * Credits


INTRODUCTION
------------
This module integrates Owl Carousel, a touch enabled jQuery plugin that lets you create a beautiful, responsive carousel sliders.

 * For a full description of the module visit:
   https://www.drupal.org/project/owlcarousel

 * To submit bug reports and feature suggestions, or to track changes visit:
   https://www.drupal.org/project/issues/owlcarousel


REQUIREMENTS
------------

This module requires owlcarousel2 library. Check installation section
for downloading the library.


FEATURES
--------

 * Responsive
 * Touch Events
 * Mouse Slide Events
 * Fully Customizable
 * Choose the number of items to be displayed
 * Multiple Sliders
 * CSS3 3d Transitions
 * Custimizable controls
 * JSON
 * Custom events
 * Helpful callbacks

  Drupal 8 & 9 Version
  --------------------
   * Field formatter
   * Views plugin


INSTALLATION
------------

 * Use any of the below methods for installing the module.


 Installation with drush
 -----------------------

   * composer require 'drupal/owlcarousel'
   * drush owlcarousel2:plugin


 Installation with composer
 --------------------------

   * composer require 'drupal/owlcarousel:^2.0@RC'
   * composer config repositories.owlcarousel2 '{"type":"package","package":{"name":"owlcarousel2/  owlcarousel2","version":"2.3.4","type":"drupal-library","dist":{"type":"zip","url":"https://github.com/OwlCarousel2/OwlCarousel2/archive/2.3.4.zip"}}}'
   * composer require owlcarousel2/owlcarousel2


 Manual installation
 -------------------

  * Download the [2.3.4 OwlCarousel2](https://github.com/OwlCarousel2/OwlCarousel2/archive/refs/tags/2.3.4.zip) release from [Github](https://github.com/OwlCarousel2/OwlCarousel2)
  * Change the directory name to owlcarousel2
  * Add directory to your libraries directory so the path becomes
    /libraries/owlcarousel2/dist/owl.carousel.js


CONFIGURATION
-------------

 * Field formatter: See video: https://www.youtube.com/watch?v=PzBMJqkNHQ0
 * Views integrated see video: https://www.youtube.com/watch?v=kKps02rc3pE


MAINTAINERS
-----------

 * Nicolas Borda [ipwa](https://www.drupal.org/u/ipwa)
 * Nicholas James [swim](https://www.drupal.org/u/swim)
 * Julian Pustkuchen [Anybody](https://www.drupal.org/u/anybody)
 * Alex Burrows [aburrows](https://www.drupal.org/u/aburrows)
 * HEBL [HEBL](https://www.drupal.org/u/hebl)
 * Thomas Frobieter [thomas.frobieter](https://www.drupal.org/u/thomasfrobieter)
 * Sébastien MALOT [Sebastien @Hubside](https://www.drupal.org/u/sebastien-hubside)


CREDITS
-------

 * Anish Sheela [anisha](https://www.drupal.org/u/anisha)
 * Daniele Monchiero [idas](https://www.drupal.org/u/idas)
 * Chennakesavulu Chakka [chakkche](https://www.drupal.org/u/chakkche)

==> owlcarousel-3.0.1.tar.gz: owlcarousel/README.md <==
CONTENTS OF THIS FILE
---------------------

 * Introduction
 * Requirements
 * Features
 * Installation
 * Configuration
 * Maintainers
 * Credits


INTRODUCTION
------------
This module integrates Owl Carousel,
a touch enabled jQuery plugin that lets you create a beautiful,
 responsive carousel sliders.

 * For a full description of the module visit:
   https://www.drupal.org/project/owlcarousel

 * To submit bug reports and feature suggestions, or to track changes visit:
   https://www.drupal.org/project/issues/owlcarousel


REQUIREMENTS
------------

This module requires owlcarousel2 library. Check installation section
for downloading the library.


FEATURES
--------

 * Responsive
 * Touch Events
 * Mouse Slide Events
 * Fully Customizable
 * Choose the number of items to be displayed
 * Multiple Sliders
 * CSS3 3d Transitions
 * Custimizable controls
 * JSON
 * Custom events
 * Helpful callbacks

  Drupal 8 & 9 Version
  --------------------
   * Field formatter
   * Views plugin


INSTALLATION
------------

 * Use any of the below methods for installing the module.


 Installation with drush
 -----------------------

   * composer require 'drupal/owlcarousel'
   * drush owlcarousel2:plugin


 Installation with composer
 --------------------------

   * composer require 'drupal/owlcarousel:^2.0@RC'
   * composer config repositories.owlcarousel2 '{"type":"package","package":{"name":"owlcarousel2/  owlcarousel2","version":"2.3.4","type":"drupal-library","dist":{"type":"zip","url":"https://github.com/OwlCarousel2/OwlCarousel2/archive/2.3.4.zip"}}}'
   * composer require owlcarousel2/owlcarousel2


 Manual installation
 -------------------

  * Download the [2.3.4 OwlCarousel2](https://github.com/OwlCarousel2/OwlCarousel2/archive/refs/tags/2.3.4.zip) release from [Github](https://github.com/OwlCarousel2/OwlCarousel2)
  * Change the directory name to owlcarousel2
  * Add directory to your libraries directory so the path becomes
    /libraries/owlcarousel2/dist/owl.carousel.js


CONFIGURATION
-------------

 * Field formatter: See video: https://www.youtube.com/watch?v=PzBMJqkNHQ0
 * Views integrated see video: https://www.youtube.com/watch?v=kKps02rc3pE


MAINTAINERS
-----------

 * Nicolas Borda [ipwa](https://www.drupal.org/u/ipwa)
 * Nicholas James [swim](https://www.drupal.org/u/swim)
 * Julian Pustkuchen [Anybody](https://www.drupal.org/u/anybody)
 * Alex Burrows [aburrows](https://www.drupal.org/u/aburrows)
 * HEBL [HEBL](https://www.drupal.org/u/hebl)
 * Thomas Frobieter [thomas.frobieter](https://www.drupal.org/u/thomasfrobieter)
 * Sébastien MALOT [Sebastien @Hubside](https://www.drupal.org/u/sebastien-hubside)


CREDITS
-------

 * Anish Sheela [anisha](https://www.drupal.org/u/anisha)
 * Daniele Monchiero [idas](https://www.drupal.org/u/idas)
 * Chennakesavulu Chakka [chakkche](https://www.drupal.org/u/chakkche)
